@@ -26,7 +26,8 @@ def lazy_load(
 
 mock_acm = lazy_load(".acm", "mock_acm")
 mock_apigateway = lazy_load(".apigateway", "mock_apigateway")
-mock_appsync = lazy_load(".appsync", "mock_appsync", boto3_name="appsync")
+mock_apigatewayv2 = lazy_load(".apigatewayv2", "mock_apigatewayv2")
+mock_appsync = lazy_load(".appsync", "mock_appsync")
 mock_athena = lazy_load(".athena", "mock_athena")
 mock_applicationautoscaling = lazy_load(
     ".applicationautoscaling", "mock_applicationautoscaling"
@@ -63,6 +64,11 @@ mock_ec2 = lazy_load(".ec2", "mock_ec2")
 mock_ec2instanceconnect = lazy_load(".ec2instanceconnect", "mock_ec2instanceconnect")
 mock_ecr = lazy_load(".ecr", "mock_ecr")
 mock_ecs = lazy_load(".ecs", "mock_ecs")
+mock_efs = lazy_load(".efs", "mock_efs")
+mock_eks = lazy_load(".eks", "mock_eks")
+mock_elasticache = lazy_load(
+    ".elasticache", "mock_elasticache", boto3_name="elasticache"
+)
 mock_elastictranscoder = lazy_load(".elastictranscoder", "mock_elastictranscoder")
 mock_elb = lazy_load(".elb", "mock_elb")
 mock_elbv2 = lazy_load(".elbv2", "mock_elbv2")
@@ -81,9 +87,22 @@ mock_iam = lazy_load(".iam", "mock_iam")
 mock_iot = lazy_load(".iot", "mock_iot")
 mock_iotdata = lazy_load(".iotdata", "mock_iotdata", boto3_name="iot-data")
 mock_kinesis = lazy_load(".kinesis", "mock_kinesis")
+mock_kinesisvideo = lazy_load(".kinesisvideo", "mock_kinesisvideo")
+mock_kinesisvideoarchivedmedia = lazy_load(
+    ".kinesisvideoarchivedmedia",
+    "mock_kinesisvideoarchivedmedia",
+    boto3_name="kinesis-video-archived-media",
+)
 mock_kms = lazy_load(".kms", "mock_kms")
 mock_logs = lazy_load(".logs", "mock_logs")
 mock_managedblockchain = lazy_load(".managedblockchain", "mock_managedblockchain")
+mock_mediaconnect = lazy_load(".mediaconnect", "mock_mediaconnect")
+mock_medialive = lazy_load(".medialive", "mock_medialive")
+mock_mediapackage = lazy_load(".mediapackage", "mock_mediapackage")
+mock_mediastore = lazy_load(".mediastore", "mock_mediastore")
+mock_mediastoredata = lazy_load(
+    ".mediastoredata", "mock_mediastoredata", boto3_name="mediastore-data"
+)
 mock_mq = lazy_load(".mq", "mock_mq", boto3_name="mq")
 mock_opsworks = lazy_load(".opsworks", "mock_opsworks")
 mock_organizations = lazy_load(".organizations", "mock_organizations")
@@ -105,6 +124,7 @@ mock_route53resolver = lazy_load(
 mock_s3 = lazy_load(".s3", "mock_s3")
 mock_s3control = lazy_load(".s3control", "mock_s3control")
 mock_sagemaker = lazy_load(".sagemaker", "mock_sagemaker")
+mock_sdb = lazy_load(".sdb", "mock_sdb")
 mock_secretsmanager = lazy_load(".secretsmanager", "mock_secretsmanager")
 mock_ses = lazy_load(".ses", "mock_ses")
 mock_sns = lazy_load(".sns", "mock_sns")
@@ -115,6 +135,7 @@ mock_stepfunctions = lazy_load(
     ".stepfunctions", "mock_stepfunctions", backend="stepfunction_backends"
 )
 mock_sts = lazy_load(".sts", "mock_sts")
+mock_support = lazy_load(".support", "mock_support")
 mock_swf = lazy_load(".swf", "mock_swf")
 mock_timestreamwrite = lazy_load(
     ".timestreamwrite", "mock_timestreamwrite", boto3_name="timestream-write"
@@ -123,27 +144,7 @@ mock_transcribe = lazy_load(".transcribe", "mock_transcribe")
 XRaySegment = lazy_load(".xray", "XRaySegment")
 mock_xray = lazy_load(".xray", "mock_xray")
 mock_xray_client = lazy_load(".xray", "mock_xray_client")
-mock_kinesisvideo = lazy_load(".kinesisvideo", "mock_kinesisvideo")
-mock_kinesisvideoarchivedmedia = lazy_load(
-    ".kinesisvideoarchivedmedia",
-    "mock_kinesisvideoarchivedmedia",
-    boto3_name="kinesis-video-archived-media",
-)
-mock_medialive = lazy_load(".medialive", "mock_medialive")
-mock_support = lazy_load(".support", "mock_support")
-mock_mediaconnect = lazy_load(".mediaconnect", "mock_mediaconnect")
-mock_mediapackage = lazy_load(".mediapackage", "mock_mediapackage")
-mock_mediastore = lazy_load(".mediastore", "mock_mediastore")
-mock_eks = lazy_load(".eks", "mock_eks")
-mock_mediastoredata = lazy_load(
-    ".mediastoredata", "mock_mediastoredata", boto3_name="mediastore-data"
-)
-mock_efs = lazy_load(".efs", "mock_efs")
 mock_wafv2 = lazy_load(".wafv2", "mock_wafv2")
-mock_sdb = lazy_load(".sdb", "mock_sdb")
-mock_elasticache = lazy_load(
-    ".elasticache", "mock_elasticache", boto3_name="elasticache"
-)
 
 
 class MockAll(ContextDecorator):
@@ -172,7 +173,7 @@ mock_all = MockAll
 # logging.getLogger('boto').setLevel(logging.CRITICAL)
 
 __title__ = "moto"
-__version__ = "3.0.2"
+__version__ = "3.0.3"
 
 
 try:
