@@ -41,7 +41,7 @@ class LeafNode(Node):
     """A LeafNode is a Node where none of the children are Nodes themselves."""
 
     def __init__(self, children=None):
-        super(LeafNode, self).__init__(children)
+        super().__init__(children)
 
 
 class Expression(Node, metaclass=abc.ABCMeta):
@@ -184,7 +184,7 @@ class ExpressionSelector(LeafNode):
 
     def __init__(self, selection_index):
         try:
-            super(ExpressionSelector, self).__init__(children=[int(selection_index)])
+            super().__init__(children=[int(selection_index)])
         except ValueError:
             assert (
                 False
@@ -198,7 +198,7 @@ class ExpressionAttribute(LeafNode):
     """An attribute identifier as used in the DDB item"""
 
     def __init__(self, attribute):
-        super(ExpressionAttribute, self).__init__(children=[attribute])
+        super().__init__(children=[attribute])
 
     def get_attribute_name(self):
         return self.children[0]
@@ -208,7 +208,7 @@ class ExpressionAttributeName(LeafNode):
     """An ExpressionAttributeName is an alias for an attribute identifier"""
 
     def __init__(self, attribute_name):
-        super(ExpressionAttributeName, self).__init__(children=[attribute_name])
+        super().__init__(children=[attribute_name])
 
     def get_attribute_name_placeholder(self):
         return self.children[0]
@@ -218,7 +218,7 @@ class ExpressionAttributeValue(LeafNode):
     """An ExpressionAttributeValue is an alias for an value"""
 
     def __init__(self, value):
-        super(ExpressionAttributeValue, self).__init__(children=[value])
+        super().__init__(children=[value])
 
     def get_value_name(self):
         return self.children[0]
@@ -228,7 +228,7 @@ class ExpressionValueOperator(LeafNode):
     """An ExpressionValueOperator is an operation that works on 2 values"""
 
     def __init__(self, value):
-        super(ExpressionValueOperator, self).__init__(children=[value])
+        super().__init__(children=[value])
 
     def get_operator(self):
         return self.children[0]
@@ -257,7 +257,7 @@ class DDBTypedValue(Node):
 
     def __init__(self, value):
         assert isinstance(value, DynamoType), "DDBTypedValue must be of DynamoType"
-        super(DDBTypedValue, self).__init__(children=[value])
+        super().__init__(children=[value])
 
     def get_value(self):
         return self.children[0]
@@ -267,7 +267,7 @@ class NoneExistingPath(LeafNode):
     """A placeholder for Paths that did not exist in the Item."""
 
     def __init__(self, creatable=False):
-        super(NoneExistingPath, self).__init__(children=[creatable])
+        super().__init__(children=[creatable])
 
     def is_creatable(self):
         """Can this path be created if need be. For example path creating element in a dictionary or creating a new
