@@ -10,8 +10,6 @@ from enum import Enum, unique
 from json import JSONDecodeError
 from operator import lt, le, eq, ge, gt
 
-from boto3 import Session
-
 from collections import OrderedDict
 from moto.core.exceptions import JsonRESTError
 from moto.core import ACCOUNT_ID, BaseBackend, CloudFormationModel, BaseModel
@@ -19,6 +17,7 @@ from moto.core.utils import (
     unix_time,
     unix_time_millis,
     iso_8601_datetime_without_milliseconds,
+    BackendDict,
 )
 from moto.events.exceptions import (
     ValidationException,
@@ -1070,7 +1069,7 @@ class EventsBackend(BaseBackend):
         return False
 
     @paginate(pagination_model=PAGINATION_MODEL)
-    def list_rule_names_by_target(self, target_arn, next_token=None, limit=None):
+    def list_rule_names_by_target(self, target_arn):
         matching_rules = []
 
         for _, rule in self.rules.items():
@@ -1081,7 +1080,7 @@ class EventsBackend(BaseBackend):
         return matching_rules
 
     @paginate(pagination_model=PAGINATION_MODEL)
-    def list_rules(self, prefix=None, next_token=None, limit=None):
+    def list_rules(self, prefix=None):
         match_string = ".*"
         if prefix is not None:
             match_string = "^" + prefix + match_string
@@ -1806,10 +1805,4 @@ class EventsBackend(BaseBackend):
         return {}
 
 
-events_backends = {}
-for region in Session().get_available_regions("events"):
-    events_backends[region] = EventsBackend(region)
-for region in Session().get_available_regions("events", partition_name="aws-us-gov"):
-    events_backends[region] = EventsBackend(region)
-for region in Session().get_available_regions("events", partition_name="aws-cn"):
-    events_backends[region] = EventsBackend(region)
+events_backends = BackendDict(EventsBackend, "events")
